==> haskell-typed-process-0.2.11.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 typed-process
version:              0.2.11.1
visibility:           public
id:                   typed-process-0.2.11.1-DGDR3UukNNr6KYu6LMJFIt
key:                  typed-process-0.2.11.1-DGDR3UukNNr6KYu6LMJFIt
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://github.com/fpco/typed-process#readme>

category:             System
abi:                  82011cc9da85025cd14ff661abcc4bd6
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-9.2.8/site-local/typed-process-0.2.11.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/typed-process-0.2.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typed-process
hs-libraries:         HStyped-process-0.2.11.1-DGDR3UukNNr6KYu6LMJFIt
depends:
    async-2.2.5-GOT0v2vzV5iH7iWkyOUIC3 base-4.16.4.0
    bytestring-0.11.4.0 process-1.6.16.0 stm-2.5.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typed-process-0.2.11.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typed-process.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 typed-process
version:              0.2.11.1
visibility:           public
id:                   typed-process-0.2.11.1-FCN86rMxmDKKyrUl0mHEsn
key:                  typed-process-0.2.11.1-FCN86rMxmDKKyrUl0mHEsn
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/typed-process
synopsis:             Run external processes, with strong typing of streams
description:
    Please see the tutorial at <https://github.com/fpco/typed-process#readme>

category:             System
abi:                  39f726e548c0dfbaefb90e64f6727fe3
exposed:              True
exposed-modules:      System.Process.Typed System.Process.Typed.Internal
hidden-modules:       Paths_typed_process
import-dirs:          /usr/lib/ghc-9.2.8/site-local/typed-process-0.2.11.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/typed-process-0.2.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typed-process
hs-libraries:         HStyped-process-0.2.11.1-FCN86rMxmDKKyrUl0mHEsn
depends:
    async-2.2.5-C7wSBqUZtbTIGwzJcB5Zmf base-4.16.4.0
    bytestring-0.11.4.0 process-1.6.16.0 stm-2.5.0.2
    transformers-0.5.6.2 unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:
    /usr/share/doc/haskell-typed-process/html/typed-process.haddock

haddock-html:         /usr/share/doc/haskell-typed-process/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
